# `dkmri` (WORK IN PROGRESS)

Reproducible and efficient diffusion kurtosis tensor estimation in Python.

## Installation

`dkmri` can be installed with [pip](https://pypi.org/):

```
pip install dkmri
```

## Usage example

`dkmri` can be used from the command line. To see an usage example and an
explanation of the parameters, execute the following:

```
dkmri.py -h
```